Module component

Module component 

Contains all component for prefab logic

Re-exports

pub use shape::*;
pub use material::*;
pub use camera::*;
pub use player_start::*;

Modules

camera
Module contatins structures for determining camera
ext
External dependencies
material
Module contatins structures for determining standart material
path
NOT USED. Planned to be used in future for auto structs
player_start
Module contatins structures for determining player start
shape
Module contatins structures for determining mesh shapes

Structs

AssetMaterial
Component to define path to material asset that will be loaded after prefab spawn
AssetMesh
Component to define path to mesh asset that will be loaded after prefab spawn
AutoStruct
Not used right now. Planned to be easy method for creating prefab structs from usual structs with assets
EntityLink
This component used in prefab to determine links between entities. It is needed to create custom UI in bevy_inspector_egui. You must implement the MapEntities trait for your component to make it work. See the FollowCamera struct from examples/platformer.rs.
GltfPrefab
Component to define path to gltf asset that will be loaded after prefab spawn
SceneAutoChild
Marker for entities spawned from gltf scene