FileDialog

Struct FileDialog 

pub struct FileDialog { /* private fields */ }
egui component that represents OpenFileDialog or SaveFileDialog.

Implementations

Source

impl FileDialog

pub fn select_folder(initial_path: Option<PathBuf>) -> FileDialog

Create dialog that prompts the user to select a folder.

pub fn open_file(initial_path: Option<PathBuf>) -> FileDialog

Create dialog that prompts the user to open a file.

pub fn save_file(initial_path: Option<PathBuf>) -> FileDialog

Create dialog that prompts the user to save a file.

pub fn default_filename(self, filename: impl Into<String>) -> FileDialog

Set the default file name.

pub fn title(self, title: &str) -> FileDialog

Set the window title text.

pub fn id(self, id: impl Into<Id>) -> FileDialog

Set the window ID.

pub fn anchor(self, align: Align2, offset: impl Into<Vec2>) -> FileDialog

Set the window anchor.

pub fn current_pos(self, current_pos: impl Into<Pos2>) -> FileDialog

Set the window position.

pub fn default_size(self, default_size: impl Into<Vec2>) -> FileDialog

Set the window default size.

pub fn resizable(self, resizable: bool) -> FileDialog

Enable/disable resizing the window. Default is true.

pub fn show_rename(self, rename: bool) -> FileDialog

Show the Rename button. Default is true.

pub fn show_new_folder(self, new_folder: bool) -> FileDialog

Show the New Folder button. Default is true.

pub fn filter( self, filter: Box<dyn Fn(&Path) -> bool + Sync + Send>, ) -> FileDialog

Set a function to filter shown files.

pub fn edit_focus( self, edit_focus: Box<dyn Fn(bool) + Sync + Send>, ) -> FileDialog

Calls the edit_focus function when a text edit gains or looses focus.

pub fn dialog_type(&self) -> DialogType

Get the dialog type.

pub fn visible(&self) -> bool

Get the window’s visibility.

pub fn open(&mut self)

Opens the dialog.

pub fn path(&self) -> Option<&Path>

Resulting file path.

pub fn set_path(&mut self, path: impl Into<PathBuf>)

Set the dialog’s current opened path

pub fn state(&self) -> State

Dialog state.

pub fn selected(&self) -> bool

Returns true, if the file selection was confirmed.

pub fn show(&mut self, ctx: &Context) -> &FileDialog

Shows the dialog if it is open. It is also responsible for state management. Should be called every ui update.