pub struct Capsule {
pub radius: f32,
pub rings: usize,
pub depth: f32,
pub latitudes: usize,
pub longitudes: usize,
pub uv_profile: CapsuleUvProfile,
}Expand description
A cylinder with hemispheres at the top and bottom
Fields
radius: f32Radius on the XZ plane.
rings: usizeNumber of sections in cylinder between hemispheres.
depth: f32Height of the middle cylinder on the Y axis, excluding the hemispheres.
latitudes: usizeNumber of latitudes, distributed by inclination. Must be even.
longitudes: usizeNumber of longitudes, or meridians, distributed by azimuth.
uv_profile: CapsuleUvProfileManner in which UV coordinates are distributed vertically.