pub struct EventReader<'w, 's, E>where
E: Event,{ /* private fields */ }Expand description
Reads events of type T in order and tracks which events have already been read.
Implementations
Sourceimpl<'w, 's, E> EventReader<'w, 's, E>where
E: Event,
impl<'w, 's, E> EventReader<'w, 's, E>where
E: Event,
Sourcepub fn read(&mut self) -> EventIterator<'_, E>
pub fn read(&mut self) -> EventIterator<'_, E>
Iterates over the events this EventReader has not seen yet. This updates the
EventReader’s event counter, which means subsequent event reads will not include events
that happened before now.
Sourcepub fn iter(&mut self) -> EventIterator<'_, E>
👎Deprecated: use .read() instead.
pub fn iter(&mut self) -> EventIterator<'_, E>
use .read() instead.
Iterates over the events this EventReader has not seen yet. This updates the
EventReader’s event counter, which means subsequent event reads will not include events
that happened before now.
Sourcepub fn read_with_id(&mut self) -> EventIteratorWithId<'_, E>
pub fn read_with_id(&mut self) -> EventIteratorWithId<'_, E>
Sourcepub fn iter_with_id(&mut self) -> EventIteratorWithId<'_, E>
👎Deprecated: use `.read_with_id() instead.
pub fn iter_with_id(&mut self) -> EventIteratorWithId<'_, E>
use `.read_with_id() instead.
Sourcepub fn len(&self) -> usize
pub fn len(&self) -> usize
Determines the number of events available to be read from this EventReader without consuming any.
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Returns true if there are no events available to read.
Example
The following example shows a useful pattern where some behavior is triggered if new events are available.
EventReader::clear() is used so the same events don’t re-trigger the behavior the next time the system runs.
#[derive(Event)]
struct CollisionEvent;
fn play_collision_sound(mut events: EventReader<CollisionEvent>) {
if !events.is_empty() {
events.clear();
// Play a sound
}
}Sourcepub fn clear(&mut self)
pub fn clear(&mut self)
Consumes all available events.
This means these events will not appear in calls to EventReader::iter() or
EventReader::iter_with_id() and EventReader::is_empty() will return true.
For usage, see EventReader::is_empty().