pub struct ImageBundle {Show 13 fields
pub node: Node,
pub style: Style,
pub calculated_size: ContentSize,
pub background_color: BackgroundColor,
pub image: UiImage,
pub image_size: UiImageSize,
pub focus_policy: FocusPolicy,
pub transform: Transform,
pub global_transform: GlobalTransform,
pub visibility: Visibility,
pub inherited_visibility: InheritedVisibility,
pub view_visibility: ViewVisibility,
pub z_index: ZIndex,
}Expand description
A UI node that is an image
Fields
node: NodeDescribes the logical size of the node
style: StyleStyles which control the layout (size and position) of the node and it’s children In some cases these styles also affect how the node drawn/painted.
calculated_size: ContentSizeThe calculated size based on the given image
background_color: BackgroundColorThe background color, which serves as a “fill” for this node
Combines with UiImage to tint the provided image.
image: UiImageThe image of the node
image_size: UiImageSizeThe size of the image in pixels
This component is set automatically
focus_policy: FocusPolicyWhether this node should block interaction with lower nodes
transform: TransformThe transform of the node
This component is automatically managed by the UI layout system.
To alter the position of the ImageBundle, use the properties of the Style component.
global_transform: GlobalTransformThe global transform of the node
This component is automatically updated by the TransformPropagate systems.
visibility: VisibilityDescribes the visibility properties of the node
inherited_visibility: InheritedVisibilityInherited visibility of an entity.
view_visibility: ViewVisibilityAlgorithmically-computed indication of whether an entity is visible and should be extracted for rendering
z_index: ZIndexIndicates the depth at which the node should appear in the UI