MaterialNodeBundle

Struct MaterialNodeBundle 

pub struct MaterialNodeBundle<M>
where M: UiMaterial,
{ pub node: Node, pub style: Style, pub material: Handle<M>, pub focus_policy: FocusPolicy, pub transform: Transform, pub global_transform: GlobalTransform, pub visibility: Visibility, pub inherited_visibility: InheritedVisibility, pub view_visibility: ViewVisibility, pub z_index: ZIndex, }
A UI node that is rendered using a UiMaterial

Adding a BackgroundColor component to an entity with this bundle will ignore the custom material and use the background color instead.

Fields

node: Node

Describes the logical size of the node

style: Style

Styles which control the layout (size and position) of the node and it’s children In some cases these styles also affect how the node drawn/painted.

material: Handle<M>

The UiMaterial used to render the node.

focus_policy: FocusPolicy

Whether this node should block interaction with lower nodes

transform: Transform

The transform of the node

This field is automatically managed by the UI layout system. To alter the position of the NodeBundle, use the properties of the Style component.

global_transform: GlobalTransform

The global transform of the node

This field is automatically managed by the UI layout system. To alter the position of the NodeBundle, use the properties of the Style component.

visibility: Visibility

Describes the visibility properties of the node

inherited_visibility: InheritedVisibility

Inherited visibility of an entity.

view_visibility: ViewVisibility

Algorithmically-computed indication of whether an entity is visible and should be extracted for rendering

z_index: ZIndex

Indicates the depth at which the node should appear in the UI