pub struct Ray {
pub origin: Vec3,
pub direction: Vec3,
}Expand description
A ray is an infinite line starting at origin, going in direction.
Fields
origin: Vec3The origin of the ray.
direction: Vec3A normalized vector representing the direction of the ray.
Implementations