pub struct RemovedComponents<'w, 's, T>where
T: Component,{ /* private fields */ }Expand description
A SystemParam that grants access to the entities that had their T Component removed.
This acts effectively the same as an EventReader.
Note that this does not allow you to see which data existed before removal.
If you need this, you will need to track the component data value on your own,
using a regularly scheduled system that requests Query<(Entity, &T), Changed<T>>
and stores the data somewhere safe to later cross-reference.
If you are using bevy_ecs as a standalone crate,
note that the RemovedComponents list will not be automatically cleared for you,
and will need to be manually flushed using World::clear_trackers
For users of bevy and bevy_app, this is automatically done in bevy_app::App::update.
For the main world, World::clear_trackers is run after the main schedule is run and after
SubApp’s have run.
Examples
Basic usage:
fn react_on_removal(mut removed: RemovedComponents<MyComponent>) {
removed.iter().for_each(|removed_entity| println!("{:?}", removed_entity));
}Implementations
Sourceimpl<'w, 's, T> RemovedComponents<'w, 's, T>where
T: Component,
impl<'w, 's, T> RemovedComponents<'w, 's, T>where
T: Component,
Sourcepub fn reader(&self) -> &ManualEventReader<RemovedComponentEntity>
pub fn reader(&self) -> &ManualEventReader<RemovedComponentEntity>
Fetch underlying ManualEventReader.
Sourcepub fn reader_mut(&mut self) -> &mut ManualEventReader<RemovedComponentEntity>
pub fn reader_mut(&mut self) -> &mut ManualEventReader<RemovedComponentEntity>
Fetch underlying ManualEventReader mutably.
Sourcepub fn reader_mut_with_events(
&mut self,
) -> Option<(&mut RemovedComponentReader<T>, &Events<RemovedComponentEntity>)>
pub fn reader_mut_with_events( &mut self, ) -> Option<(&mut RemovedComponentReader<T>, &Events<RemovedComponentEntity>)>
Destructures to get a mutable reference to the ManualEventReader
and a reference to Events.
This is necessary since Rust can’t detect destructuring through methods and most
usecases of the reader uses the Events as well.
Sourcepub fn read(
&mut self,
) -> Map<Flatten<IntoIter<Cloned<EventIterator<'_, RemovedComponentEntity>>>>, fn(RemovedComponentEntity) -> Entity>
pub fn read( &mut self, ) -> Map<Flatten<IntoIter<Cloned<EventIterator<'_, RemovedComponentEntity>>>>, fn(RemovedComponentEntity) -> Entity>
Iterates over the events this RemovedComponents has not seen yet. This updates the
RemovedComponents’s event counter, which means subsequent event reads will not include events
that happened before now.
Sourcepub fn iter(
&mut self,
) -> Map<Flatten<IntoIter<Cloned<EventIterator<'_, RemovedComponentEntity>>>>, fn(RemovedComponentEntity) -> Entity>
👎Deprecated: use .read() instead.
pub fn iter( &mut self, ) -> Map<Flatten<IntoIter<Cloned<EventIterator<'_, RemovedComponentEntity>>>>, fn(RemovedComponentEntity) -> Entity>
use .read() instead.
Iterates over the events this RemovedComponents has not seen yet. This updates the
RemovedComponents’s event counter, which means subsequent event reads will not include events
that happened before now.
Sourcepub fn read_with_id(
&mut self,
) -> Map<Flatten<IntoIter<EventIteratorWithId<'_, RemovedComponentEntity>>>, fn((&RemovedComponentEntity, EventId<RemovedComponentEntity>)) -> (Entity, EventId<RemovedComponentEntity>)>
pub fn read_with_id( &mut self, ) -> Map<Flatten<IntoIter<EventIteratorWithId<'_, RemovedComponentEntity>>>, fn((&RemovedComponentEntity, EventId<RemovedComponentEntity>)) -> (Entity, EventId<RemovedComponentEntity>)>
Sourcepub fn iter_with_id(
&mut self,
) -> Map<Flatten<IntoIter<EventIteratorWithId<'_, RemovedComponentEntity>>>, fn((&RemovedComponentEntity, EventId<RemovedComponentEntity>)) -> (Entity, EventId<RemovedComponentEntity>)>
👎Deprecated: use .read_with_id() instead.
pub fn iter_with_id( &mut self, ) -> Map<Flatten<IntoIter<EventIteratorWithId<'_, RemovedComponentEntity>>>, fn((&RemovedComponentEntity, EventId<RemovedComponentEntity>)) -> (Entity, EventId<RemovedComponentEntity>)>
use .read_with_id() instead.
Sourcepub fn len(&self) -> usize
pub fn len(&self) -> usize
Determines the number of removal events available to be read from this RemovedComponents without consuming any.
Sourcepub fn clear(&mut self)
pub fn clear(&mut self)
Consumes all available events.
This means these events will not appear in calls to RemovedComponents::read() or
RemovedComponents::read_with_id() and RemovedComponents::is_empty() will return true.