AudioBundle

Type Alias AudioBundle 

pub type AudioBundle = AudioSourceBundle;
Bundle for playing a standard bevy audio asset

Aliased Type

pub struct AudioBundle {
    pub source: Handle<AudioSource>,
    pub settings: PlaybackSettings,
}

Fields

source: Handle<AudioSource>

Asset containing the audio data to play.

settings: PlaybackSettings

Initial settings that the audio starts playing with. If you would like to control the audio while it is playing, query for the AudioSink component. Changes to this component will not be applied to already-playing audio.