pub struct FileDialog { /* private fields */ }Expand description
egui component that represents OpenFileDialog or SaveFileDialog.
Implementations
Sourceimpl FileDialog
impl FileDialog
Sourcepub fn select_folder(initial_path: Option<PathBuf>) -> FileDialog
pub fn select_folder(initial_path: Option<PathBuf>) -> FileDialog
Create dialog that prompts the user to select a folder.
Sourcepub fn open_file(initial_path: Option<PathBuf>) -> FileDialog
pub fn open_file(initial_path: Option<PathBuf>) -> FileDialog
Create dialog that prompts the user to open a file.
Sourcepub fn save_file(initial_path: Option<PathBuf>) -> FileDialog
pub fn save_file(initial_path: Option<PathBuf>) -> FileDialog
Create dialog that prompts the user to save a file.
Sourcepub fn default_filename(self, filename: impl Into<String>) -> FileDialog
pub fn default_filename(self, filename: impl Into<String>) -> FileDialog
Set the default file name.
Sourcepub fn title(self, title: &str) -> FileDialog
pub fn title(self, title: &str) -> FileDialog
Set the window title text.
Sourcepub fn id(self, id: impl Into<Id>) -> FileDialog
pub fn id(self, id: impl Into<Id>) -> FileDialog
Set the window ID.
Sourcepub fn anchor(self, align: Align2, offset: impl Into<Vec2>) -> FileDialog
pub fn anchor(self, align: Align2, offset: impl Into<Vec2>) -> FileDialog
Set the window anchor.
Sourcepub fn current_pos(self, current_pos: impl Into<Pos2>) -> FileDialog
pub fn current_pos(self, current_pos: impl Into<Pos2>) -> FileDialog
Set the window position.
Sourcepub fn default_size(self, default_size: impl Into<Vec2>) -> FileDialog
pub fn default_size(self, default_size: impl Into<Vec2>) -> FileDialog
Set the window default size.
Sourcepub fn resizable(self, resizable: bool) -> FileDialog
pub fn resizable(self, resizable: bool) -> FileDialog
Enable/disable resizing the window. Default is true.
Sourcepub fn show_rename(self, rename: bool) -> FileDialog
pub fn show_rename(self, rename: bool) -> FileDialog
Show the Rename button. Default is true.
Sourcepub fn show_new_folder(self, new_folder: bool) -> FileDialog
pub fn show_new_folder(self, new_folder: bool) -> FileDialog
Show the New Folder button. Default is true.
Sourcepub fn filter(
self,
filter: Box<dyn Fn(&Path) -> bool + Sync + Send>,
) -> FileDialog
pub fn filter( self, filter: Box<dyn Fn(&Path) -> bool + Sync + Send>, ) -> FileDialog
Set a function to filter shown files.
Sourcepub fn edit_focus(
self,
edit_focus: Box<dyn Fn(bool) + Sync + Send>,
) -> FileDialog
pub fn edit_focus( self, edit_focus: Box<dyn Fn(bool) + Sync + Send>, ) -> FileDialog
Calls the edit_focus function when a text edit gains or looses focus.
Sourcepub fn dialog_type(&self) -> DialogType
pub fn dialog_type(&self) -> DialogType
Get the dialog type.
Sourcepub fn show(&mut self, ctx: &Context) -> &FileDialog
pub fn show(&mut self, ctx: &Context) -> &FileDialog
Shows the dialog if it is open. It is also responsible for state management. Should be called every ui update.